@@ -22,4 +22,7 @@ from dhlab.text.parse import NER, POS, Models
 from dhlab.ngram.ngram import Ngram, NgramBook, NgramNews
 
 # wordbank 
-from dhlab.wordbank.wordbank import WordParadigm, WordLemma, WordForm
\ No newline at end of file
+from dhlab.wordbank.wordbank import WordParadigm, WordLemma, WordForm
+
+# api
+from dhlab.api.dhlab_api import totals
\ No newline at end of file
