@@ -2,6 +2,7 @@ from typing import Union, List, Tuple, Dict
 
 import pandas as pd
 import requests
+from requests import HTTPError, JSONDecodeError, ConnectionError
 from pandas import DataFrame, Series
 
 from dhlab.constants import BASE_URL
@@ -24,7 +25,7 @@ def images(text = None, part=True):
     js = r.json()
     return js
 
-def ner_from_urn(urn: str = None, model: str = None) -> DataFrame:
+def ner_from_urn(urn: str = None, model: str = None, start_page = 0, to_page = 0) -> DataFrame:
     """Get NER annotations for a text (``urn``) using a spacy ``model``.
 
     :param str urn: uniform resource name, example: ``URN:NBN:no-nb_digibok_2011051112001``
@@ -39,7 +40,7 @@ def ner_from_urn(urn: str = None, model: str = None) -> DataFrame:
     return df
 
 
-def pos_from_urn(urn: str = None, model: str = None) -> DataFrame:
+def pos_from_urn(urn: str = None, model: str = None, start_page = 0, to_page = 0) -> DataFrame:
     """Get part of speech tags and dependency parse annotations for a text (``urn``) with a SpaCy ``model``.
 
     :param str urn: uniform resource name, example: ``URN:NBN:no-nb_digibok_2011051112001``
@@ -53,10 +54,16 @@ def pos_from_urn(urn: str = None, model: str = None) -> DataFrame:
     return df
 
 
-def show_spacy_models():
+def show_spacy_models() -> List:
     """Show available SpaCy model names."""
-    r = requests.get(f"{BASE_URL}/ner_models")
-    return r.json()
+    try:
+        r = requests.get(f"{BASE_URL}/ner_models")
+        r.raise_for_status()
+        return r.json()
+    except (HTTPError, JSONDecodeError, ConnectionError) as error:
+        print(error.__doc__, error)
+        print("Server-request gikk ikke gjennom. Kan ikke vise SpaCy-modellnavn.")
+        return []
 
 
 def get_places(urn: str) -> DataFrame:
@@ -605,7 +612,7 @@ def urn_collocation(
         "samplesize": samplesize,
     }
     r = requests.post(BASE_URL + "/urncolldist_urn", json=params)
-    return pd.read_json(r.text)
+    return pd.read_json(r.json())
 
 
 def totals(top_words: int = 50000) -> DataFrame:
@@ -694,7 +701,7 @@ def collocation(
         "after": after,
     }
     r = requests.post(BASE_URL + "/urncolldist", json=params)
-    return pd.read_json(r.text)
+    return pd.read_json(r.json())
 
 
 # Norwegian word bank
